==> aslsocial-0.0.1-20121207.164718-6-sources.jar: org/gcube/applicationsupportlayer/social/AslNotificationManager.java <==
package org.gcube.applicationsupportlayer.social;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.common.core.utils.logging.GCUBEClientLog;
import org.gcube.portal.databook.server.DBCassandraAstyanaxImpl;
import org.gcube.portal.databook.server.DatabookStore;
import org.gcube.portal.databook.shared.Comment;
import org.gcube.portal.databook.shared.Feed;
import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceFolder;
import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceItem;
import org.gcube.portlets.user.homelibrary.home.workspace.sharing.WorkspaceMessage;
/**
 * 
 * @author Massimiliano Assante, ISTI-CNR
 * @version 0.1 Dec 2012
 *
 */
public class AslNotificationManager implements NotificationManager {
	GCUBEClientLog log = new GCUBEClientLog(AslNotificationManager.class);

	private ASLSession session;
	private DatabookStore store;
	
	public AslNotificationManager(ASLSession session) {
		this.session = session;
	}

	@Override
	public boolean notifyFolderSharing(String userIdToNotify, WorkspaceFolder sharedFolder) {
		return true;
	}

	@Override
	public boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String newAddedUserId) {
		return true;
	}

	@Override
	public boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String removedUserId) {
		return true;
	}

	@Override
	public boolean notifyAddedItem(String userIdToNotify, WorkspaceItem newItem) {
		return true;
	}

	@Override
	public boolean notifyRemovedItem(String userIdToNotify,	WorkspaceItem removedItem) {
		return true;
	}

	@Override
	public boolean notifyUpdatedItem(String userIdToNotify,	WorkspaceItem updatedItem) {
		return true;
	}

	@Override
	public boolean notifyMessageReceived(String userIdToNotify,	WorkspaceMessage message) {
		return true;
	}

	@Override
	public boolean notifyOwnCommentReply(String userIdToNotify, Comment comment) {
		return true;
	}

	@Override
	public boolean notifyCommentReply(String userIdToNotify, Comment comment) {
		return true;
	}

	@Override
	public boolean notifyLikedFeed(String userIdToNotify, Feed likedFeed) {
		return true;
	}
	

}

==> aslsocial-0.0.1-20121207.173619-7-sources.jar: org/gcube/applicationsupportlayer/social/AslNotificationManager.java <==
package org.gcube.applicationsupportlayer.social;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.common.core.utils.logging.GCUBEClientLog;
import org.gcube.portal.databook.server.DBCassandraAstyanaxImpl;
import org.gcube.portal.databook.server.DatabookStore;
import org.gcube.portal.databook.shared.Comment;
import org.gcube.portal.databook.shared.Feed;
import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceFolder;
import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceItem;
import org.gcube.portlets.user.homelibrary.home.workspace.sharing.WorkspaceMessage;
/**
 * 
 * @author Massimiliano Assante, ISTI-CNR
 * @version 0.1 Dec 2012
 *
 * use to notify users from within your application 
 */
public class AslNotificationManager implements NotificationManager {
	GCUBEClientLog log = new GCUBEClientLog(AslNotificationManager.class);

	private ASLSession session;
	private DatabookStore store;
	
	public AslNotificationManager(ASLSession session) {
		this.session = session;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyFolderSharing(String userIdToNotify, WorkspaceFolder sharedFolder) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyFolderAddedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String newAddedUserId) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String removedUserId) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyAddedItem(String userIdToNotify, WorkspaceItem newItem) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyRemovedItem(String userIdToNotify,	WorkspaceItem removedItem) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyUpdatedItem(String userIdToNotify,	WorkspaceItem updatedItem) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyMessageReceived(String userIdToNotify,	WorkspaceMessage message) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyOwnCommentReply(String userIdToNotify, Comment comment) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyCommentReply(String userIdToNotify, Comment comment) {
		return true;
	}
	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean notifyLikedFeed(String userIdToNotify, Feed likedFeed) {
		return true;
	}
	

}
